summaryrefslogtreecommitdiff
path: root/src/script/api/script_gamesettings.hpp
diff options
context:
space:
mode:
authortruebrain <truebrain@openttd.org>2011-11-29 23:15:35 +0000
committertruebrain <truebrain@openttd.org>2011-11-29 23:15:35 +0000
commit98103121d4f2ed1f1581919b7b1f343ccd410c12 (patch)
tree1e760dd6517a6b0f9fb669ec277139a8e3f9a4a3 /src/script/api/script_gamesettings.hpp
parentafdb67a3534f85b4efbd3327ece8137211042d7b (diff)
downloadopenttd-98103121d4f2ed1f1581919b7b1f343ccd410c12.tar.xz
(svn r23355) -Codechange: rename all AI* to Script* (Rubidium)
Diffstat (limited to 'src/script/api/script_gamesettings.hpp')
-rw-r--r--src/script/api/script_gamesettings.hpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/script/api/script_gamesettings.hpp b/src/script/api/script_gamesettings.hpp
index 07efd630e..8643df5de 100644
--- a/src/script/api/script_gamesettings.hpp
+++ b/src/script/api/script_gamesettings.hpp
@@ -17,24 +17,24 @@
/**
* Class that handles all game settings related functions.
*
* @note AIGameSettings::IsValid and AIGameSettings::GetValue are functions
* that rely on the settings as OpenTTD stores them in savegame and
* openttd.cfg. No guarantees can be given on the long term validity,
* consistency and stability of the names, values and value ranges.
* Using these settings can be dangerous and could cause issues in
* future versions. To make sure that a setting still exists in the
* current version you have to run AIGameSettings::IsValid before
* accessing it.
*
* @note The names of the setting for AIGameSettings::IsValid and
* AIGameSettings::GetValue are the same ones as those that are shown by
* the list_settings command in the in-game console. Settings that are
* string based are NOT supported and AIGAmeSettings::IsValid will return
* false for them. These settings will not be supported either because
* they have no relevance for the AI (default client names, server IPs,
* etc.).
*/
-class AIGameSettings : public AIObject {
+class ScriptGameSettings : public ScriptObject {
public:
/**
* Is the given game setting a valid setting for this instance of OpenTTD?
@@ -65,7 +65,7 @@ public:
* @param vehicle_type The vehicle-type to check.
* @return True if the vehicle-type is disabled.
*/
- static bool IsDisabledVehicleType(AIVehicle::VehicleType vehicle_type);
+ static bool IsDisabledVehicleType(ScriptVehicle::VehicleType vehicle_type);
};
#endif /* SCRIPT_GAMESETTINGS_HPP */
@@ -17,24 +17,24 @@
* Class that handles all game settings related functions.
*
- * @note AIGameSettings::IsValid and AIGameSettings::GetValue are functions
+ * @note ScriptGameSettings::IsValid and ScriptGameSettings::GetValue are functions
* that rely on the settings as OpenTTD stores them in savegame and
* openttd.cfg. No guarantees can be given on the long term validity,
@@ -17,24 +17,24 @@
* Using these settings can be dangerous and could cause issues in
* future versions. To make sure that a setting still exists in the
- * current version you have to run AIGameSettings::IsValid before
+ * current version you have to run ScriptGameSettings::IsValid before
* accessing it.
*
@@ -17,24 +17,24 @@
* accessing it.
*
- * @note The names of the setting for AIGameSettings::IsValid and
- * AIGameSettings::GetValue are the same ones as those that are shown by
+ * @note The names of the setting for ScriptGameSettings::IsValid and
+ * ScriptGameSettings::GetValue are the same ones as those that are shown by
* the list_settings command in the in-game console. Settings that are
* string based are NOT supported and AIGAmeSettings::IsValid will return